==> kyt-1.2.5.tgz: package/lib/utils/printAssets.js <==
"use strict";

// Prints webpack asset stats
var fs = require('fs');

var path = require('path');

var filesize = require('filesize');

var gzipSize = require('gzip-size');

var stripAnsi = require('strip-ansi');

var logger = require('kyt-utils/logger');

module.exports = function (stats, clientConfig) {
  var assetPath = clientConfig.output.path;
  var assets = stats.toJson().assets.filter(function (asset) {
    return /\.(js|css)$/.test(asset.name);
  }).map(function (asset) {
    var file = fs.readFileSync(path.resolve(assetPath, asset.name));
    var gzSize = gzipSize.sync(file);
    return {
      folder: path.join('build/public', path.dirname(asset.name)),
      gzSize: gzSize,
      gzSizeLabel: "(".concat(filesize(gzSize), " gzip)"),
      name: path.basename(asset.name),
      size: asset.size,
      sizeLabel: filesize(asset.size)
    };
  });
  assets.sort(function (a, b) {
    return b.size - a.size;
  });
  var longestSizeLabelLength = Reflect.apply(Math.max, null, assets.map(function (a) {
    return stripAnsi(a.sizeLabel).length;
  }));
  var longestGzSizeLabelLength = Reflect.apply(Math.max, null, assets.map(function (a) {
    return stripAnsi(a.gzSizeLabel).length;
  }));

  var addLabelPadding = function addLabelPadding(label, longestLength) {
    var padded = label; // eslint-disable-next-line prefer-destructuring

    var length = stripAnsi(label).length;

    if (length < longestLength) {
      var rightPadding = ' '.repeat(longestLength - length);
      padded += rightPadding;
    }

    return padded;
  };

  assets.forEach(function (asset) {
    var sizeLabel = addLabelPadding(asset.sizeLabel, longestSizeLabelLength);
    var gzSizeLabel = addLabelPadding(asset.gzSizeLabel, longestGzSizeLabelLength);
    logger.log("    ".concat(sizeLabel, "    ").concat(gzSizeLabel, "    ").concat(asset.folder + path.sep + asset.name));
  });
};

==> kyt-1.2.9.tgz: package/lib/utils/printAssets.js <==
"use strict";

// Prints webpack asset stats
var fs = require('fs');
var path = require('path');
var filesize = require('filesize');
var gzipSize = require('gzip-size');
var stripAnsi = require('strip-ansi');
var logger = require('kyt-utils/logger');
module.exports = function (stats, clientConfig) {
  var assetPath = clientConfig.output.path;
  var assets = stats.toJson().assets.filter(function (asset) {
    return /\.(js|css)$/.test(asset.name);
  }).map(function (asset) {
    var file = fs.readFileSync(path.resolve(assetPath, asset.name));
    var gzSize = gzipSize.sync(file);
    return {
      folder: path.join('build/public', path.dirname(asset.name)),
      gzSize: gzSize,
      gzSizeLabel: "(".concat(filesize(gzSize), " gzip)"),
      name: path.basename(asset.name),
      size: asset.size,
      sizeLabel: filesize(asset.size)
    };
  });
  assets.sort(function (a, b) {
    return b.size - a.size;
  });
  var longestSizeLabelLength = Reflect.apply(Math.max, null, assets.map(function (a) {
    return stripAnsi(a.sizeLabel).length;
  }));
  var longestGzSizeLabelLength = Reflect.apply(Math.max, null, assets.map(function (a) {
    return stripAnsi(a.gzSizeLabel).length;
  }));
  var addLabelPadding = function addLabelPadding(label, longestLength) {
    var padded = label;
    // eslint-disable-next-line prefer-destructuring
    var length = stripAnsi(label).length;
    if (length < longestLength) {
      var rightPadding = ' '.repeat(longestLength - length);
      padded += rightPadding;
    }
    return padded;
  };
  assets.forEach(function (asset) {
    var sizeLabel = addLabelPadding(asset.sizeLabel, longestSizeLabelLength);
    var gzSizeLabel = addLabelPadding(asset.gzSizeLabel, longestGzSizeLabelLength);
    logger.log("    ".concat(sizeLabel, "    ").concat(gzSizeLabel, "    ").concat(asset.folder + path.sep + asset.name));
  });
};
